
#ifndef __file_view_cclosure_marshal_MARSHAL_H__
#define __file_view_cclosure_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* VOID:OBJECT,BOOLEAN,INT,INT (file-view-marshal.list:1) */
extern void file_view_cclosure_marshal_VOID__OBJECT_BOOLEAN_INT_INT (GClosure     *closure,
                                                                     GValue       *return_value,
                                                                     guint         n_param_values,
                                                                     const GValue *param_values,
                                                                     gpointer      invocation_hint,
                                                                     gpointer      marshal_data);

G_END_DECLS

#endif /* __file_view_cclosure_marshal_MARSHAL_H__ */

